==> python-language-24.1.1.jar: module-info.java <==
module org.graalvm.py {
    requires com.oracle.truffle.regex;
    requires com.oracle.truffle.tools.profiler;
    requires com.oracle.truffle.truffle_nfi;
    requires com.oracle.truffle.truffle_nfi_libffi;
    requires java.logging;
    requires java.management;
    requires jdk.management;
    requires jdk.security.auth;
    requires jdk.unsupported;
    requires org.bouncycastle.pkix;
    requires org.bouncycastle.provider;
    requires org.bouncycastle.util;
    requires org.graalvm.collections;
    requires org.graalvm.llvm.api;
    requires org.graalvm.nativeimage;
    requires org.graalvm.polyglot;
    requires org.graalvm.shadowed.icu4j;
    requires org.graalvm.shadowed.xz;
    requires org.graalvm.truffle;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.graal.python.annotations to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ast to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.bz2 to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.cext to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.cjkcodecs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.codecs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.csv to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ctypes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ctypes.memory to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.functools to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.hashlib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.io to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.json to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.lzma to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.multiprocessing to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.pickle to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.zlib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.array to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.asyncio to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.bool to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.buffer to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.bytes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.capsule to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cell to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.capi to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.capi.transitions to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.common to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy.jni to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy.llvm to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.structs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.code to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.common to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.complex to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.contextvars to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.deque to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.dict to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ellipsis to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.enumerate to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.floats to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.foreign to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.frame to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.function to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.generator to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.getsetdescriptor to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ints to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.iterator to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.itertools to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.list to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.map to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.mappingproxy to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.memoryview to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.method to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.mmap to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.module to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.namespace to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ordereddict to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.posix to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.property to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.queue to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.random to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.range to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.referencetype to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.reversed to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.set to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.slice to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.socket to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ssl to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.str to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.struct to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.superobject to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.thread to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.traceback to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.tuple to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.type to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.type.slots to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.types to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.charset to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.compiler to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.lib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument.keywords to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument.positional to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.attributes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.bytecode to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.bytecode.instrumentation to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.call to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.call.special to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.classes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.expression to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.frame to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function.builtins.clinic to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.instrumentation to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.interop to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.statement to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.truffle to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.util to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.scope to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.sst to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.tokenizer to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.formatting to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.interop to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.locale to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.native_memory to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.sequence to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.sequence.storage to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.util to org.graalvm.py.enterprise;

    provides TruffleLanguageProvider with PythonLanguageProvider;

}

==> python-language-24.2.1.jar: module-info.java <==
module org.graalvm.py {
    requires com.oracle.truffle.regex;
    requires com.oracle.truffle.tools.profiler;
    requires com.oracle.truffle.truffle_nfi;
    requires com.oracle.truffle.truffle_nfi_libffi;
    requires java.logging;
    requires java.management;
    requires jdk.management;
    requires jdk.security.auth;
    requires jdk.unsupported;
    requires org.bouncycastle.pkix;
    requires org.bouncycastle.provider;
    requires org.bouncycastle.util;
    requires org.graalvm.collections;
    requires org.graalvm.llvm.api;
    requires org.graalvm.nativeimage;
    requires org.graalvm.polyglot;
    requires org.graalvm.shadowed.icu4j;
    requires org.graalvm.shadowed.xz;
    requires org.graalvm.truffle;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.graal.python.annotations to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ast to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.bz2 to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.cext to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.cjkcodecs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.codecs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.csv to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ctypes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.ctypes.memory to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.functools to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.hashlib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.io to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.json to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.lzma to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.multiprocessing to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.pickle to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.modules.zlib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.array to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.asyncio to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.bool to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.buffer to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.bytes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.capsule to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cell to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.capi to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.capi.transitions to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.common to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.copying to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy.jni to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.hpy.llvm to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.cext.structs to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.code to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.common to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.complex to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.contextvars to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.deque to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.dict to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ellipsis to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.enumerate to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.floats to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.foreign to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.frame to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.function to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.generator to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.getsetdescriptor to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ints to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.iterator to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.itertools to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.list to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.map to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.mappingproxy to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.memoryview to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.method to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.mmap to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.module to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.namespace to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ordereddict to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.posix to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.property to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.queue to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.random to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.range to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.referencetype to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.reversed to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.set to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.slice to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.socket to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.ssl to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.str to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.struct to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.superobject to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.thread to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.tokenize to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.traceback to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.tuple to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.type to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.type.slots to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.builtins.objects.types to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.charset to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.compiler to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.lib to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument.keywords to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.argument.positional to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.arrow to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.arrow.capsule to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.arrow.release_callback to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.arrow.vector to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.attributes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.bytecode to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.bytecode.instrumentation to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.call to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.call.special to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.classes to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.expression to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.frame to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function.builtins to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.function.builtins.clinic to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.instrumentation to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.interop to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.statement to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.truffle to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.nodes.util to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.scope to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.sst to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.pegparser.tokenizer to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.arrow to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.exception to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.formatting to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.interop to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.locale to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.native_memory to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.object to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.sequence to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.runtime.sequence.storage to org.graalvm.py.enterprise;
    exports com.oracle.graal.python.util to org.graalvm.py.enterprise;

    provides TruffleLanguageProvider with PythonLanguageProvider;

}
